@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,19 +30,6 @@ CommandHandler::CommandHandler(GlobalObject *globalObject,
     m_mucManager = m_globalObject->getMucManager();
     m_variableParser = m_globalObject->getVariableParser();
 
-
-    // Give seed based on current time to random number generator
-    uint randomSeed;
-    randomSeed = QTime::currentTime().hour()
-               + (QTime::currentTime().minute() * 4)
-               + (QTime::currentTime().second() * 5)
-               + (QTime::currentTime().msec() * 6);
-    randomSeed *= 8;
-    randomSeed += qrand() % (randomSeed / (QTime::currentTime().second() + 1));
-
-    qsrand(randomSeed);
-
-
     qDebug() << "CommandHandler created";
 }
 
@@ -322,7 +309,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
                                                     .trimmed();
                         QStringList linesList = fileLines.split("\n");
 
-                        int lineNum = qrand() % linesList.length();
+                        int lineNum = QRandomGenerator::global()->bounded(linesList.length());
                         if (lineNum < linesList.length())
                         {
                             commandReply = linesList.at(lineNum).trimmed();
