@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -28,13 +28,18 @@
 
 #include <QDebug>
 
+#include "globalobject.h"
+#include "roomspeaktab.h"
+#include "stringlistwidget.h"
+
 
 class ConversationModule : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit ConversationModule(QWidget *parent = nullptr);
+    explicit ConversationModule(GlobalObject *globalObject,
+                                QWidget *parent = nullptr);
     ~ConversationModule();
 
 
@@ -44,10 +49,13 @@ signals:
 public slots:
 
 
+
 private:
     QVBoxLayout *m_mainLayout;
 
-    QTreeWidget *m_conversationTreeWidget;
+    RoomSpeakTab *m_conversationTab;
+
+    GlobalObject *m_globalObject;
 
 };
 
