@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -423,6 +423,16 @@ void GlobalObject::sendPrivateMessage(QString jid, QString message)
     emit privateMessageSent(jid, message);
 }
 
+
+void GlobalObject::sendMessageState(QString jid, QXmppMessage::State state)
+{
+    QXmppMessage stateStanza;
+    stateStanza.setTo(jid);
+    stateStanza.setState(state);
+    m_xmppClient->sendPacket(stateStanza);
+}
+
+
 /*
  * Request empty tab to be added in ChatModule, and the module to be focused
  *
