@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -36,9 +36,11 @@ Helpers::~Helpers()
 bool Helpers::isValidJid(QString jid)
 {
     // Matching something@something, and only one @ sign
-    if (QRegExp("\\S+@\\S+").exactMatch(jid) && jid.count("@") == 1)
+    QRegularExpression re("\\S+@\\S+");
+    QRegularExpressionMatch reMatch = re.match(jid);
+
+    if (reMatch.hasMatch() && jid.count("@") == 1)
     {
-        // FIXME: port to QRegularExpression
         return true;
     }
 
@@ -89,7 +91,7 @@ QString Helpers::randomString(QStringList stringList)
 
     if (!stringList.isEmpty())
     {
-        const int choice = qrand() % stringList.length();
+        const int choice = QRandomGenerator::global()->bounded(stringList.length());
         if (choice >= 0 && choice < stringList.length()) // For safety
         {
             chosenString = stringList.at(choice);
@@ -140,11 +142,7 @@ int Helpers::randomBetween(int lowNum, int highNum)
         qSwap(lowNum, highNum);
     }
 
-    highNum -= lowNum;
-
-    int randomNumber = qrand() % (highNum + 1);
-    randomNumber += lowNum;
-
+    int randomNumber = QRandomGenerator::global()->bounded(lowNum, highNum + 1);
 
     return randomNumber;
 }
@@ -156,7 +154,7 @@ int Helpers::randomBetween(int lowNum, int highNum)
  */
 bool Helpers::probability(int chancePercent)
 {
-    const int randomNumber = qrand() % 100; // Random between 0 and 100
+    const int randomNumber = QRandomGenerator::global()->bounded(101); // Random between 0 and 100
 
     if (randomNumber < chancePercent)
     {
