@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ private:
     QLineEdit *m_nickLineEdit;
     QDateEdit *m_dobDateEdit;
 
-    QPushButton *m_updateButton;
+    QPushButton *m_saveButton;
 
     DataFile *m_dataFile;
 
