@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -61,8 +61,8 @@ LogModule::~LogModule()
 void LogModule::addToLog(QString message, int messageType)
 {
     QString logLine = "<b>["
-                      + QDate::currentDate()
-                              .toString(Qt::DefaultLocaleShortDate)
+                      + QLocale::system().toString(QDate::currentDate(),
+                                                   QLocale::ShortFormat)
                       + " &nbsp;" // 2 space separation
                       + QTime::currentTime().toString() // Default HH:MM:SS
                       + "]</b> ";
