@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -45,13 +45,13 @@ int main(int argc, char *argv[])
 {
     QApplication akariApp(argc, argv);
     akariApp.setApplicationName(QStringLiteral("AkariXB"));
-    akariApp.setApplicationVersion(QStringLiteral("0.9"));
+    akariApp.setApplicationVersion(QStringLiteral("1.0"));
     akariApp.setOrganizationName(QStringLiteral("JanCoding"));
     akariApp.setOrganizationDomain(QStringLiteral("jancoding.wordpress.com"));
     // This is mainly needed for window managers under Wayland
-    akariApp.setDesktopFileName(QStringLiteral("org.nongnu.akarixb.desktop"));
+    akariApp.setDesktopFileName(QStringLiteral("org.nongnu.akarixb"));
 
-    std::cout << QString("AkariXB v%1 - JanKusanagi 2015-2022\n"
+    std::cout << QString("AkariXB v%1 - JanKusanagi 2015-2025\n"
                          "https://jancoding.wordpress.com/akarixb\n\n")
                  .arg(akariApp.applicationVersion())
                  .toStdString();
