@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -37,11 +37,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
 #if 0 // Set to 1 to test the fallback icons
-    QIcon::setThemeName("SHOW_ME_FALLBACK_ICONS_THX");
     // This one since Qt 5.12
- #if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
-     QIcon::setFallbackThemeName("SRSLY_GIVE_ME_FALLBACK_ICONS");
- #endif
+    QIcon::setFallbackThemeName("SHOW_ME_FALLBACK_ICONS_THX");
 #endif
 
     setupXmppClient();
@@ -107,7 +104,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     m_roomSpeakModule = new RoomSpeakModule(m_globalObject, this);
 
     // Page 7, conversations
-    m_conversationModule = new ConversationModule(this);
+    m_conversationModule = new ConversationModule(m_globalObject, this);
 
     // Page 8, activities
     m_activityModule = new ActivityModule(m_activityHandler,
@@ -233,6 +230,13 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(m_initialConnectionTimer, &QTimer::timeout,
             this, &MainWindow::onConnectionTimerAbort);
 
+    // Handle reconnections with a timer, with increasing delays up to 2 min or so
+    m_reconnectionTimer = new QTimer(this);
+    m_reconnectionTimer->setSingleShot(true);
+    connect(m_reconnectionTimer, &QTimer::timeout,
+            this, &MainWindow::autoConnectToServer);
+    m_reconnectionDelaySecs = 0;
+
 
     this->setStatusBarMessage(tr("Ready."));
 
@@ -456,7 +460,7 @@ void MainWindow::createStatusBarWidgets()
 
 void MainWindow::createDataDir()
 {
-    const QString dataDirectory = QStandardPaths::standardLocations(QStandardPaths::DataLocation)
+    const QString dataDirectory = QStandardPaths::standardLocations(QStandardPaths::AppLocalDataLocation)
                                                  .first();
 
     m_globalObject->setDataDirectory(dataDirectory);
@@ -654,6 +658,15 @@ void MainWindow::setStatusIconOnline(QXmppPresence::AvailableStatusType statusTy
 }
 
 
+void MainWindow::increaseReconnectionTimeout()
+{
+    if (m_reconnectionDelaySecs < 120)
+    {
+        m_reconnectionDelaySecs += 10;
+    }
+}
+
+
 
 //////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////// SLOTS //////////////////////////////////
@@ -686,7 +699,7 @@ void MainWindow::connectToServer(QString jid, QString password,
     clientConfig.setPassword(m_userPassword);
     clientConfig.setKeepAliveInterval(m_globalObject->getKeepAliveInterval());
     clientConfig.setKeepAliveTimeout(m_globalObject->getKeepAliveTimeout());
-    clientConfig.setAutoReconnectionEnabled(false);
+    clientConfig.setAutoReconnectionEnabled(false); // QXMPP autoreconnect kinda sucks
     clientConfig.setIgnoreSslErrors(m_ignoreSslErrors);
     if (m_ignoreSslErrors)
     {
@@ -699,12 +712,15 @@ void MainWindow::connectToServer(QString jid, QString password,
     m_disconnectedManually = false;
     m_initialConnectionTimer->start();
 
+    qDebug() << QTime::currentTime().toString()
+             << "Connecting to" << m_userJid;
     m_xmppClient->connectToServer(clientConfig);
 }
 
 
 void MainWindow::autoConnectToServer()
 {
+    qDebug() << "Autoconnecting to server...";
     this->connectToServer(m_userJid,
                           m_userPassword,
                           m_userAutoconnect,
@@ -723,6 +739,9 @@ void MainWindow::onConnected()
 
     m_initialConnectionTimer->stop();
 
+    m_reconnectionTimer->stop();
+    m_reconnectionDelaySecs = 0; // Connection successful, so reset
+
     QStringList statusMessages;    // TMP hardcoded 'default' messages
     statusMessages << "H{i|ii|iii}!"
                    << "I'm h{e|ee|eee}re{!|!!}"
@@ -768,6 +787,9 @@ void MainWindow::disconnectFromServer()
     m_xmppClient->disconnectFromServer();
 
     m_sessionAbortAction->setDisabled(true);
+
+    m_reconnectionTimer->stop();
+    m_reconnectionDelaySecs = 0; // Reset
 }
 
 
@@ -778,6 +800,9 @@ void MainWindow::abortConnectionAttempts()
     const QString message = tr("Aborted connection attempt.");
     m_generalModule->setInfoMessage(message);
     m_globalObject->addToLog(message, true, GlobalObject::LogBad);
+    qDebug() << QTime::currentTime().toString()
+             << "Aborted connection attempt";
+
 
     // Enable 'Connect' action here regardless of when onDisconnected() runs,
     // since there's a race condition in some cases
@@ -792,7 +817,7 @@ void MainWindow::onDisconnected()
     const QString message = tr("Disconnected.");
     m_generalModule->setInfoMessage(message);
     m_globalObject->addToLog(message, true, GlobalObject::LogBad);
-    qDebug() << "\n" << QTime::currentTime().toString() << "\n"
+    qDebug() << "\n" << QDateTime::currentDateTime().toString() << "\n"
                 "\n=========================================================="
                 "\n======================-DISCONNECTED-======================"
                 "\n=========================================================="
@@ -817,7 +842,12 @@ void MainWindow::onDisconnected()
 
         // TODO: optional email notification for this event
 
-        this->autoConnectToServer(); // FIXME: autoreconnection should be optional
+        // Don't reconnect directly here to avoid crashes
+        this->increaseReconnectionTimeout();
+        m_reconnectionTimer->start(m_reconnectionDelaySecs * 1000);
+        qDebug() << "Reconnecting again in" << m_reconnectionDelaySecs << "seconds";
+
+        // FIXME: autoreconnection should be optional
     }
 }
 
@@ -836,7 +866,13 @@ void MainWindow::onConnectionTimerAbort()
     m_initialConnectionTimer->stop();
     m_xmppClient->disconnectFromServer(); // Set it to disconnected state, to
     m_disconnectedManually = false;       // avoid 'Trying to connect while
-    this->autoConnectToServer();          // connection is in progress'
+                                          // connection is in progress'
+
+    // Don't reconnect directly here to avoid crashes
+    this->increaseReconnectionTimeout();
+    m_reconnectionTimer->start(m_reconnectionDelaySecs * 1000);
+    qDebug() << "Attempting connection again in" << m_reconnectionDelaySecs
+             << "seconds";
 }
 
 
@@ -1017,8 +1053,10 @@ void MainWindow::onNetworkError(QXmppClient::Error error)
         break;
 
     case QXmppClient::XmppStreamError:
-        errorString = tr("XMPP Stream Error");
-        qDebug() << "::: XMPP Stream Error:" << m_xmppClient->xmppStreamError();
+        errorString = tr("XMPP Stream Error")
+                      + " (" + m_xmppClient->socketErrorString() + ")";
+        qDebug() << "::: XMPP Stream Error:" << m_xmppClient->xmppStreamError()
+                 << m_xmppClient->socketErrorString();
         break;
 
     default:
@@ -1030,7 +1068,8 @@ void MainWindow::onNetworkError(QXmppClient::Error error)
                             .arg("<b>" + errorString + "</b>");
     m_globalObject->addToLog(message, true, GlobalObject::LogBad);
 
-    //qDebug() << "Network error:"
+    qDebug() << QDateTime::currentDateTime().toString()
+             << "Network error:" << errorString;
     //         << "\nStanza:" << this->xmppClient->xmppStreamError()
     //         << "\nSocket:" << this->xmppClient->socketErrorString();
 }
@@ -1097,7 +1136,7 @@ void MainWindow::aboutAkariXB()
                        QString("<big><b>AkariXB v%1</b></big>")
                        .arg(qApp->applicationVersion())
                        + "<br />"
-                         "Copyright 2015-2022  JanKusanagi<br />"
+                         "Copyright 2015-2025  JanKusanagi<br />"
                          "<a href=\"https://jancoding.wordpress.com/akarixb\">"
                          "https://jancoding.wordpress.com/akarixb</a><br />"
                          "<br />"
@@ -1235,7 +1274,6 @@ void MainWindow::showNotification(QString title, QString message)
             title.append(QString(" (%1)").arg(m_userJid));
         }
 
-        // This themed icon overload requires Qt 5.9+, but QXMPP already requires it
         m_systrayIcon->showMessage(title,
                                    message,
                                    QIcon::fromTheme("akarixb",
@@ -1340,6 +1378,16 @@ void MainWindow::quitProgram()
 
 void MainWindow::resizeEvent(QResizeEvent *event)
 {
+    // FIXME, basic hardcoded adjustment to icons for smaller window sizes
+    if (this->width() > 1024 && this->height() > 700)
+    {
+        m_categoriesList->setIconSize(QSize(48, 48));
+    }
+    else
+    {
+        m_categoriesList->setIconSize(QSize(22, 22));
+    }
+
     event->accept();
 }
 
