@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@
 #include <QMessageBox>
 #include <QResizeEvent>
 #include <QDesktopServices>
+#include <QStandardPaths> // Qt6 needs explicit include
 #include <QDir>
 #include <QTimer>
 
@@ -101,6 +102,8 @@ public:
     void setStatusIconOnline(QXmppPresence::AvailableStatusType statusType,
                              bool isOnline);
 
+    void increaseReconnectionTimeout();
+
 
 public slots:
     void connectToServer(QString jid, QString password,
@@ -206,6 +209,9 @@ private:
 
 
     QTimer *m_initialConnectionTimer;
+    QTimer *m_reconnectionTimer;
+    int m_reconnectionDelaySecs;
+
 
     // XMPP
     QXmppClient *m_xmppClient;
