@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,8 @@ MessageHandler::MessageHandler(GlobalObject *globalObject,
     m_xmppClient = m_globalObject->getXmppClient();
     m_mucManager = m_globalObject->getMucManager();
 
+    m_conversationHandler = new ConversationHandler(m_globalObject, this);
+
 
     qDebug() << "MessageHandler created";
 }
@@ -55,31 +57,46 @@ void MessageHandler::processMessage(QXmppMessage message)
         if (room != nullptr)
         {
             const QString fromNick = from.join("/");
-
-            // tmp greeting thing
-            if (message.body().startsWith(room->nickName(), Qt::CaseInsensitive)
-             && fromNick != room->nickName())
+            if (fromNick == room->nickName()) // Ensure it's not somehow from us
             {
-                if (message.body().contains("bye"))
+                return;
+            }
+
+            // FIXME: basic check for our nickname, to trigger chatroom public conversation
+            // TODO: check for "nick," and "nick:" - Also user regexps like "hey %nick%"
+            if (message.body().startsWith(room->nickName(), Qt::CaseInsensitive))
+            {
+                // Ignore conversation attempts if the room is configured to not allow it
+                if (!room->property("allowConversing").toBool())
                 {
-                    room->sendMessage(QString("Bye, %1! o/").arg(fromNick));
-                }
-                else
-                {
-                    room->sendMessage(QString("Hey %1! o/").arg(fromNick));
+                    qDebug() << "Room" << bareFrom << "doesn't allow conversing:"
+                             << message.body();
+                    return;
                 }
+
+                // FIXME: remove own nick from the beginning of the message
+                m_conversationHandler->processMessage(message.from(),
+                                                      message.body(),
+                                                      room,
+                                                      fromNick);
             }
         }
     }
     else if (message.type() == QXmppMessage::Normal
           || message.type() == QXmppMessage::Chat)
     {
-        if (!message.body().isEmpty())
+        // FIXME: pass room info if this is a private chat from inside a room (WIP)
+        if (m_globalObject->getJoinedRooms().contains(bareFrom))
         {
-            m_globalObject->sendPrivateMessage(message.from(),
-                                               m_variableParser
-                                               ->getParsed("Hi{!|!!|!!!} "
-                                                           "%smiley%")); // tmp FIXME
+            m_conversationHandler->processMessage(message.from(),
+                                                  message.body(),
+                                                  m_globalObject->roomFromJid(bareFrom),
+                                                  from.join("/"));
+        }
+        else
+        {
+            m_conversationHandler->processMessage(message.from(),
+                                                  message.body());
         }
     }
     else if (message.type() == QXmppMessage::Headline)
