@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -230,6 +230,7 @@ RoomModule::RoomModule(GlobalObject *globalObject,
 
     // Layout
     m_detailsUpperLayout = new QHBoxLayout();
+    m_detailsUpperLayout->setSpacing(2); // Avoid smaller spacing from parent layout
     m_detailsUpperLayout->addWidget(m_roomJidLineEdit,      7);
     m_detailsUpperLayout->addWidget(m_nickLineEdit,         4);
     m_detailsUpperLayout->addWidget(m_roomPasswordLineEdit, 3);
@@ -261,6 +262,7 @@ RoomModule::RoomModule(GlobalObject *globalObject,
     m_detailsExtraLayout->addWidget(m_allowConversingCheckbox, 0, Qt::AlignTop);
 
     m_detailsLayout = new QVBoxLayout();
+    m_detailsLayout->setSpacing(1);
     m_detailsLayout->addLayout(m_detailsUpperLayout);
     m_detailsLayout->addLayout(m_detailsExtraLayout);
     m_detailsLayout->addWidget(m_updateCancelButtonBox);
@@ -272,6 +274,8 @@ RoomModule::RoomModule(GlobalObject *globalObject,
 
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->setContentsMargins(0, 0, 0, 0);
+    m_mainLayout->setSpacing(1); // Small spacing to help with small resolutions, but
+                                 // not 0, which looks horrible with some Qt styles
     m_mainLayout->addWidget(m_roomTableWidget, 1);
     m_mainLayout->addLayout(m_buttonsLayout);
     m_mainLayout->addWidget(m_detailsGroupbox, 3);
@@ -434,8 +438,8 @@ void RoomModule::adjustRoomsTable()
 {
     const int oneTenthWidth = m_roomTableWidget->viewport()->width() / 10;
 
-    m_roomTableWidget->setColumnWidth(0, oneTenthWidth * 4);
-    m_roomTableWidget->setColumnWidth(1, oneTenthWidth * 3);
+    m_roomTableWidget->setColumnWidth(0, oneTenthWidth * 5);
+    m_roomTableWidget->setColumnWidth(1, oneTenthWidth * 2);
     m_roomTableWidget->setColumnWidth(2, oneTenthWidth);
     m_roomTableWidget->setColumnWidth(3, oneTenthWidth);
     m_roomTableWidget->setColumnWidth(4, oneTenthWidth);
@@ -543,7 +547,7 @@ void RoomModule::joinRoom(QString roomJid, QString nickname, QString password)
 
     m_chatStackedWidget->addWidget(newChatWidget);
     m_openedRooms.append(newChatWidget);
-
+    // FIXME: don't join if m_openedRooms already contains this room for some reason
 
     RoomSpeakHandler *newRoomSpeakHandler = new RoomSpeakHandler(m_globalObject,
                                                                  room,
