@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -39,6 +39,9 @@ RoomSpeakHandler::RoomSpeakHandler(GlobalObject *globalObject,
     connect(m_muc, &QXmppMucRoom::messageReceived,
             this, &RoomSpeakHandler::onMucMessageReceived);
 
+    // Save JID as string so we can use it at any time
+    m_mucJid = muc->jid();
+
 
     // Timer to send delayed greetings and reactions
     m_delayedMessageTimer = new QTimer(this);
@@ -61,19 +64,19 @@ RoomSpeakHandler::RoomSpeakHandler(GlobalObject *globalObject,
             this, &RoomSpeakHandler::sendCasualMessage);
 
 
-    qDebug() << "RoomSpeakHandler created";
+    qDebug() << "RoomSpeakHandler created for" << m_mucJid;
 }
 
 RoomSpeakHandler::~RoomSpeakHandler()
 {
-    qDebug() << "RoomSpeakHandler destroyed";
+    qDebug() << "RoomSpeakHandler destroyed for" << m_mucJid;
 }
 
 
 
 QString RoomSpeakHandler::getRoomJid()
 {
-    return m_muc->jid();
+    return m_mucJid;
 }
 
 
@@ -113,7 +116,7 @@ void RoomSpeakHandler::onParticipantJoined(QString jid)
     nick = Helpers::safeForHtml(nick);
 
     // Capability to auto-greet under certain conditions
-    if (m_globalObject->isRoomFullyJoined(m_muc->jid())
+    if (m_globalObject->isRoomFullyJoined(m_mucJid)
         && m_muc->property("allowGreetings").toBool()
         && Helpers::probability(m_globalObject->getAvailability())
         && Helpers::probability(m_muc->property("greetingProb").toInt())
@@ -161,7 +164,7 @@ void RoomSpeakHandler::sendDelayedMessage()
 
     qDebug() << QTime::currentTime().toString()
              << "RoomSpeakHandler, sending delayed message "
-                "(greeting/reaction) to" << m_muc->jid()
+                "(greeting/reaction) to" << m_mucJid
              << ":" << m_delayedMessage
              << "after" << m_delayedMessageTimer->interval();
 }
@@ -216,7 +219,7 @@ void RoomSpeakHandler::onMucMessageReceived(QXmppMessage message)
 {
     const QString userNick = Helpers::nickFromRoomJid(message.from());
 
-    if (m_globalObject->isRoomFullyJoined(m_muc->jid())
+    if (m_globalObject->isRoomFullyJoined(m_mucJid)
         && m_muc->property("allowCasualSpeak").toBool()
         && userNick != m_muc->nickName()
         && Helpers::probability(m_globalObject->getAvailability())
@@ -235,15 +238,24 @@ void RoomSpeakHandler::onMucMessageReceived(QXmppMessage message)
             }
 
             const QString reString = reMap.keys().first();
-            QRegularExpression re(reString);
+            QRegularExpression re(reString, // Defaulting to case insensitive for now - FIXME
+                                  QRegularExpression::CaseInsensitiveOption);
 
-            if (re.match(body).hasMatch())
+            QRegularExpressionMatch reMatch = re.match(body);
+            if (reMatch.hasMatch())
             {
                 const QStringList reactions = reMap.value(reString).toStringList();
                 m_delayedMessage = Helpers::randomString(reactions);
                 m_delayedMessage = m_variableParser->getParsed(m_delayedMessage);
                 m_delayedMessage.replace(QStringLiteral("%user%"), userNick);
 
+                // Replace %cg#% with corresponding captured groups contents
+                for (int capCount = 1; capCount <= reMatch.lastCapturedIndex(); ++capCount)
+                {
+                    m_delayedMessage.replace(QString("%cg%1%").arg(capCount), // FIXME
+                                             reMatch.captured(capCount));
+                }
+
                 this->scheduleDelayedMessage();
 
                 return;
