@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -79,7 +79,10 @@ RoomSpeakModule::RoomSpeakModule(GlobalObject *globalObject,
     // Syntax checking enabled for sub-list, not for main list, which holds regexps
     m_reactionsTab->getStringListWidget()
                   ->setSublistSyntaxEnabled(m_globalObject->getVariableParser(),
-                                            QStringList{"%user%"});
+                                            QStringList{"%user%",
+                                                        "%cg1%","%cg2%","%cg3%",
+                                                        "%cg4%","%cg5%","%cg6%",
+                                                        "%cg7%","%cg8%","%cg9%"});
 
 
 
