@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@ RoomSpeakTab::RoomSpeakTab(SentenceType tabType, QString tabTitle,
 
     m_explanationLabel = new QLabel(explanation, this);
     m_explanationLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+    m_explanationLabel->setWordWrap(true);
     m_explanationLabel->setOpenExternalLinks(true);
 
 
@@ -43,7 +44,7 @@ RoomSpeakTab::RoomSpeakTab(SentenceType tabType, QString tabTitle,
         m_stringListWidget = new StringListWidget(StringListWidget::StringsWithTags,
                                                   this);
     }
-    else // RoomSpeakTab::SentenceReaction
+    else // RoomSpeakTab::SentenceReaction || RoomSpeakTab::SentenceConversation
     {
         m_stringListWidget = new StringListWidget(StringListWidget::RegExpsWithTagsAndReplies,
                                                   this);
@@ -134,6 +135,10 @@ void RoomSpeakTab::syncToSpeechDataStore(QVariantList sentencesList)
     {
         m_speechDataStore->setReactionSentences(sentencesList);
     }
+    else if (m_tabType == RoomSpeakTab::SentenceConversation)
+    {
+        m_speechDataStore->setConversationSentences(sentencesList);
+    }
 }
 
 
