@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,8 @@ public:
     {
         SentenceGreeting,
         SentenceCasual,
-        SentenceReaction
+        SentenceReaction,
+        SentenceConversation
     };
 
     explicit RoomSpeakTab(SentenceType tabType,
