@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -83,3 +83,14 @@ QVariantList SpeechDataStore::getAllReactions()
     return m_reactionSentences;
 }
 
+
+void SpeechDataStore::setConversationSentences(QVariantList conversationSentencesList)
+{
+    m_conversationSentences = conversationSentencesList;
+}
+
+QVariantList SpeechDataStore::getAllConversationSentences()
+{
+    return m_conversationSentences;
+}
+
