@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -46,6 +46,9 @@ public:
     void setReactionSentences(QVariantList reactionSentencesList);
     QVariantList getAllReactions();
 
+    void setConversationSentences(QVariantList conversationSentencesList);
+    QVariantList getAllConversationSentences();
+
 
 signals:
 
@@ -53,11 +56,12 @@ signals:
 public slots:
 
 
+
 private:
     QVariantList m_greetingSentences;
     QVariantList m_casualSentences;
     QVariantList m_reactionSentences;
-
+    QVariantList m_conversationSentences;
 };
 
 #endif // SPEECHDATASTORE_H
