@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -89,6 +89,9 @@ StringListWidget::StringListWidget(ListType listType,
     m_tableView->setModel(m_filterModel);
     connect(m_tableView, &QTableView::doubleClicked,
             this, &StringListWidget::editItem);
+    connect(m_tableView->selectionModel(), &QItemSelectionModel::currentRowChanged,
+            this, &StringListWidget::toggleUpDownButtons);
+
 
     // Search / filter bar
     m_searchAction = new QAction(this);
@@ -165,6 +168,24 @@ StringListWidget::StringListWidget(ListType listType,
             this, &StringListWidget::removeFromList);
 
 
+    m_moveUpButton = new QToolButton(this);
+    m_moveUpButton->setIcon(QIcon::fromTheme("arrow-up",
+                                             QIcon(":/images/list-up.png")));
+    m_moveUpButton->setToolTip("<b></b>"
+                               + tr("Move the selected item up"));
+    connect(m_moveUpButton, &QAbstractButton::clicked,
+            this, &StringListWidget::moveItemUp);
+    m_moveUpButton->setDisabled(true);
+
+    m_moveDownButton = new QToolButton(this);
+    m_moveDownButton->setIcon(QIcon::fromTheme("arrow-down",
+                                               QIcon(":/images/list-down.png")));
+    m_moveDownButton->setToolTip("<b></b>"
+                                 + tr("Move the selected item down"));
+    connect(m_moveDownButton, &QAbstractButton::clicked,
+            this, &StringListWidget::moveItemDown);
+    m_moveDownButton->setDisabled(true);
+
 
     m_itemCountLabel = new QLabel(this);
     m_itemCountLabel->setAlignment(Qt::AlignCenter);
@@ -221,6 +242,10 @@ StringListWidget::StringListWidget(ListType listType,
     m_buttonsLayout->addSpacing(4);
     m_buttonsLayout->addWidget(m_removeButton);
     m_buttonsLayout->addStretch();
+    m_buttonsLayout->addWidget(m_moveUpButton);
+    m_buttonsLayout->addSpacing(4);
+    m_buttonsLayout->addWidget(m_moveDownButton);
+    m_buttonsLayout->addStretch();
     m_buttonsLayout->addWidget(m_itemCountLabel);
 
     m_mainLayout = new QHBoxLayout();
@@ -234,6 +259,7 @@ StringListWidget::StringListWidget(ListType listType,
     }
     else if (listType == RegExpsWithTagsAndReplies)
     {
+        m_mainLayout->addSpacing(4);
         m_mainLayout->addWidget(m_repliesListWidget, 1);
     }
 
@@ -578,6 +604,8 @@ void StringListWidget::enableRelevantButtons()
     m_editButton->setEnabled(buttonEnabled);
     m_removeButton->setEnabled(buttonEnabled);
 
+    toggleUpDownButtons();
+
     if (m_listType == KeysWithValues)
     {
         m_itemDataTextEdit->setEnabled(buttonEnabled);
@@ -738,6 +766,62 @@ void StringListWidget::removeFromList()
     {
         enableRelevantButtons();
     }
+
+    toggleUpDownButtons();
+}
+
+
+void StringListWidget::moveItemUp()
+{
+    QStandardItem *item = this->getCurrentTableItem();
+
+    if (item != 0)
+    {
+        const int previousRow = item->row();
+        qDebug() << "**moving item UP, from ROW " << previousRow;
+        if (previousRow > 0)
+        {
+            QList<QStandardItem *> itemsToMove = m_tableModel->takeRow(previousRow);
+            m_tableModel->insertRow(previousRow - 1, itemsToMove);
+            m_tableView->selectRow(previousRow - 1);
+
+            emit itemsChanged(); // FIXME: needed here?
+        }
+    }
+}
+
+void StringListWidget::moveItemDown()
+{
+    QStandardItem *item = this->getCurrentTableItem();
+
+    if (item != 0)
+    {
+        const int previousRow = item->row();
+        qDebug() << "**moving item DOWN, from ROW " << previousRow;
+        if (previousRow < m_tableModel->rowCount() - 1)
+        {
+            QList<QStandardItem *> itemsToMove = m_tableModel->takeRow(previousRow);
+            m_tableModel->insertRow(previousRow + 1, itemsToMove);
+            m_tableView->selectRow(previousRow + 1);
+
+            emit itemsChanged(); // FIXME: needed here?
+        }
+    }
+}
+
+void StringListWidget::toggleUpDownButtons()
+{
+    QStandardItem *item = this->getCurrentTableItem();
+    if (item != 0)
+    {
+        m_moveUpButton->setEnabled(item->row() != 0);
+        m_moveDownButton->setEnabled(item->row() < m_tableModel->rowCount() - 1);
+    }
+    else
+    {
+        m_moveUpButton->setEnabled(false);
+        m_moveDownButton->setEnabled(false);
+    }
 }
 
 
