@@ -192,6 +192,45 @@
         <source>Additional specific JIDs:</source>
         <translation>JIDs específicos adicionales:</translation>
     </message>
+    <message>
+        <source>Mon</source>
+        <comment>Monday, shortened if possible</comment>
+        <translation>Lun</translation>
+    </message>
+    <message>
+        <source>Tue</source>
+        <comment>Tuesday, shortened if possible</comment>
+        <translation>Mar</translation>
+    </message>
+    <message>
+        <source>Wed</source>
+        <comment>Wednesday, shortened if possible</comment>
+        <translation>Mie</translation>
+    </message>
+    <message>
+        <source>Thu</source>
+        <comment>Thursday, shortened if possible</comment>
+        <translation>Jue</translation>
+    </message>
+    <message>
+        <source>Fri</source>
+        <comment>Friday, shortened if possible</comment>
+        <translation>Vie</translation>
+    </message>
+    <message>
+        <source>Sat</source>
+        <comment>Saturday, shortened if possible</comment>
+        <translation>Sab</translation>
+    </message>
+    <message>
+        <source>Sun</source>
+        <comment>Sunday, shortened if possible</comment>
+        <translation>Dom</translation>
+    </message>
+    <message>
+        <source>Days Of The Week</source>
+        <translation>Días de la semana</translation>
+    </message>
 </context>
 <context>
     <name>ChatModule</name>
@@ -524,10 +563,6 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Explanation shown to users with the %1 command</source>
         <translation>Explicación mostrada a los usuarios con el comando %1</translation>
     </message>
-    <message>
-        <source>The name, without the prefix or any spaces</source>
-        <translation type="vanished">El nombre, sin el prefijo ni espacios</translation>
-    </message>
     <message>
         <source>The command name can&apos;t contain spaces.</source>
         <translation>El nombre del comando no puede contener espacios.</translation>
@@ -672,6 +707,19 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>&amp;Connect</source>
         <translation>&amp;Conectar</translation>
     </message>
+    <message>
+        <source>Use carefully.</source>
+        <translatorcomment>Meh...</translatorcomment>
+        <translation>Usar con cuidado.</translation>
+    </message>
+    <message>
+        <source>This allows connecting to servers with bad security certificates.</source>
+        <translation>Esto permite conectar a servidores con certificados de seguridad no válidos.</translation>
+    </message>
+    <message>
+        <source>Ignore SSL errors</source>
+        <translation>Ignorar errores de SSL</translation>
+    </message>
 </context>
 <context>
     <name>ContactsModule</name>
@@ -799,6 +847,10 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <comment>Number of rooms joined and configured</comment>
         <translation>Se ha entrado en %1, de %2 configuradas</translation>
     </message>
+    <message>
+        <source>Server version: %1</source>
+        <translation>Versión del servidor: %1</translation>
+    </message>
 </context>
 <context>
     <name>HelpWidget</name>
@@ -1210,6 +1262,10 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Received version information from %1:</source>
         <translation>Se ha recibido versión de información de %1:</translation>
     </message>
+    <message>
+        <source>Warning! Ignoring errors in SSL connection to server.</source>
+        <translation>¡Advertencia! Ignorando errores en la conexión SSL al servidor.</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -1351,11 +1407,6 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Greet people</source>
         <translation>Saludar a gente</translation>
     </message>
-    <message>
-        <source>Speak casually</source>
-        <translatorcomment>............. meh</translatorcomment>
-        <translation type="obsolete">Hablar de forma casual</translation>
-    </message>
     <message>
         <source>Converse</source>
         <translation>Conversar</translation>
@@ -1418,7 +1469,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     <message>
         <source>Regular expressions to be matched against messages coming from the chatrooms, and possible messages to send in response.</source>
         <translatorcomment>Meh....</translatorcomment>
-        <translation type="unfinished">Expresiones regulares con las que comparar los mensajes provenientes de las salas de charla, y posibles mensajes para enviar en respuesta.</translation>
+        <translation>Expresiones regulares con las que comparar los mensajes provenientes de las salas de charla, y posibles mensajes para enviar en respuesta.</translation>
     </message>
 </context>
 <context>
@@ -1521,7 +1572,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     <name>VariableParser</name>
     <message>
         <source>Unbalanced braces: %1 opening and %2 closing</source>
-        <translation type="unfinished">Llaves descompensadas: %1 que abren y %2 que cierran</translation>
+        <translation>Llaves descompensadas: %1 que abren y %2 que cierran</translation>
     </message>
     <message>
         <source>This substitution is unknown, or not valid in this context: %1</source>
