@@ -4,7 +4,7 @@
 <context>
     <name>ActivityHandler</name>
     <message numerus="yes">
-        <location filename="../src/activityhandler.cpp" line="211"/>
+        <location filename="../src/activityhandler.cpp" line="230"/>
         <source>%Ln hour(s)</source>
         <translation>
             <numerusform>%Ln heure</numerusform>
@@ -12,7 +12,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/activityhandler.cpp" line="222"/>
+        <location filename="../src/activityhandler.cpp" line="241"/>
         <source>%Ln minute(s)</source>
         <translation>
             <numerusform>%Ln minute</numerusform>
@@ -20,22 +20,22 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="235"/>
+        <location filename="../src/activityhandler.cpp" line="254"/>
         <source>Starting activity %1, which will end at %2.</source>
         <translation>Lancement de l&apos;activité %1, qui prendra fin à %2.</translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="336"/>
+        <location filename="../src/activityhandler.cpp" line="358"/>
         <source>Not sending message to room %1 because I am not currently in it.</source>
         <translation>Pas d&apos;envoi du message au salon %1 car je n&apos;y suis pas.</translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="381"/>
+        <location filename="../src/activityhandler.cpp" line="403"/>
         <source>Activity ended: %1.</source>
         <translation>Activité terminée : %1.</translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="388"/>
+        <location filename="../src/activityhandler.cpp" line="410"/>
         <source>None</source>
         <comment>Regarding an activity</comment>
         <translation>Aucune</translation>
@@ -58,153 +58,200 @@
         <source>&amp;Remove Activity</source>
         <translation>Supp&amp;rimer une activité</translation>
     </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="98"/>
+        <source>Mon</source>
+        <comment>Monday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="100"/>
+        <source>Tue</source>
+        <comment>Tuesday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/activitymodule.cpp" line="102"/>
+        <source>Wed</source>
+        <comment>Wednesday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="104"/>
+        <source>Thu</source>
+        <comment>Thursday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="106"/>
+        <source>Fri</source>
+        <comment>Friday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="108"/>
+        <source>Sat</source>
+        <comment>Saturday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="110"/>
+        <source>Sun</source>
+        <comment>Sunday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="117"/>
         <source>minutes</source>
         <translation>minutes</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="105"/>
+        <location filename="../src/activitymodule.cpp" line="120"/>
         <source>Online</source>
         <translation>En ligne</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="106"/>
+        <location filename="../src/activitymodule.cpp" line="121"/>
         <source>Free for Chat</source>
         <translation>Disponible</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="107"/>
+        <location filename="../src/activitymodule.cpp" line="122"/>
         <source>Away</source>
         <translation>Absent</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="108"/>
+        <location filename="../src/activitymodule.cpp" line="123"/>
         <source>Extended Away</source>
         <translation>Absence prolongée</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="109"/>
+        <location filename="../src/activitymodule.cpp" line="124"/>
         <source>Do not Disturb</source>
         <translation>Ne pas déranger</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="126"/>
+        <location filename="../src/activitymodule.cpp" line="141"/>
         <source>seconds</source>
         <translation>secondes</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="145"/>
+        <location filename="../src/activitymodule.cpp" line="160"/>
         <source>All rooms</source>
         <translation>Tous les salons</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="146"/>
+        <location filename="../src/activitymodule.cpp" line="161"/>
         <source>Several rooms</source>
         <translation>Plusieurs salons</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="147"/>
+        <location filename="../src/activitymodule.cpp" line="162"/>
         <source>A few rooms</source>
         <translation>Quelques salons</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="162"/>
+        <location filename="../src/activitymodule.cpp" line="177"/>
         <source>List of room or user addresses, separated by space</source>
         <translation>Liste des adresses de salons ou utilisateurs, séparés par un espace</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="151"/>
+        <location filename="../src/activitymodule.cpp" line="247"/>
+        <source>Days Of The Week</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="166"/>
         <source>Also to active private chats</source>
         <translation>Aussi pour les discussions privées actives</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="148"/>
+        <location filename="../src/activitymodule.cpp" line="163"/>
         <source>None of the rooms</source>
         <translation>Aucun des salons</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="157"/>
+        <location filename="../src/activitymodule.cpp" line="172"/>
         <source>Additional specific JIDs:</source>
         <translation>JID spécifiques supplémentaires :</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="169"/>
+        <location filename="../src/activitymodule.cpp" line="184"/>
         <source>Sa&amp;ve Activity</source>
         <translation>&amp;Enregister l&apos;activité</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="218"/>
+        <location filename="../src/activitymodule.cpp" line="242"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="219"/>
+        <location filename="../src/activitymodule.cpp" line="243"/>
         <source>Maximum Times Per Day</source>
         <translation>Temps maximum par jour</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="220"/>
+        <location filename="../src/activitymodule.cpp" line="244"/>
         <source>Probability</source>
         <translation>Probabilité</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="221"/>
+        <location filename="../src/activitymodule.cpp" line="245"/>
         <source>Time Range</source>
         <translation>Intervalle de temps</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="222"/>
+        <location filename="../src/activitymodule.cpp" line="246"/>
         <source>Date Range</source>
         <translation>Intervalle de dates</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="223"/>
+        <location filename="../src/activitymodule.cpp" line="248"/>
         <source>Duration</source>
         <translation>Durée</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="224"/>
+        <location filename="../src/activitymodule.cpp" line="249"/>
         <source>Set Status Type</source>
         <translation>Définir le type de statut</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="225"/>
+        <location filename="../src/activitymodule.cpp" line="250"/>
         <source>Status Messages</source>
         <translation>Messages d&apos;état</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="226"/>
+        <location filename="../src/activitymodule.cpp" line="251"/>
         <source>Availability</source>
         <translation>Disponibilité</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="227"/>
+        <location filename="../src/activitymodule.cpp" line="252"/>
         <source>Reaction Time</source>
         <translation>Temps de réaction</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="228"/>
+        <location filename="../src/activitymodule.cpp" line="253"/>
         <source>Descriptions</source>
         <translation>Descriptions</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="229"/>
+        <location filename="../src/activitymodule.cpp" line="254"/>
         <source>Messages Before</source>
         <translation>Messages avant</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="230"/>
+        <location filename="../src/activitymodule.cpp" line="255"/>
         <source>Messages Afterwards</source>
         <translation>Messages après</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="231"/>
+        <location filename="../src/activitymodule.cpp" line="256"/>
         <source>Send Messages To</source>
         <translation>Envoyer les messages à</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/activitymodule.cpp" line="309"/>
+        <location filename="../src/activitymodule.cpp" line="334"/>
         <source>Loaded %Ln activities.</source>
         <translation>
             <numerusform>Chargé %Ln activité.</numerusform>
@@ -212,22 +259,22 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="338"/>
+        <location filename="../src/activitymodule.cpp" line="363"/>
         <source>New Activity</source>
         <translation>Nouvelle activité</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="473"/>
+        <location filename="../src/activitymodule.cpp" line="514"/>
         <source>Activity exists</source>
         <translation>L&apos;activité existe</translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="474"/>
+        <location filename="../src/activitymodule.cpp" line="515"/>
         <source>Error: There is already an activity in the list with this name.</source>
         <translation>Erreur : Il existe déjà une activité dans la liste avec ce nom.</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/activitymodule.cpp" line="571"/>
+        <location filename="../src/activitymodule.cpp" line="622"/>
         <source>Saved %Ln activities.</source>
         <translation>
             <numerusform>Enregistré %Ln activité.</numerusform>
@@ -339,10 +386,6 @@
         <source>Available commands</source>
         <translation>Commandes disponibles</translation>
     </message>
-    <message>
-        <source>Command %1 requested without the right access level.</source>
-        <translation type="vanished">Commande %1 demandée sans les bons niveaux d&apos;accès.</translation>
-    </message>
     <message>
         <location filename="../src/commandhandler.cpp" line="333"/>
         <source>Error loading file %1 for command: %2</source>
@@ -359,17 +402,17 @@
         <translation>Je n&apos;ai pas de résultats pour %1</translation>
     </message>
     <message>
-        <location filename="../src/commandhandler.cpp" line="398"/>
+        <location filename="../src/commandhandler.cpp" line="399"/>
         <source>Started detached program successfully.</source>
         <translation>Le programme détaché est lancé.</translation>
     </message>
     <message>
-        <location filename="../src/commandhandler.cpp" line="435"/>
+        <location filename="../src/commandhandler.cpp" line="437"/>
         <source>Command gave no output text.</source>
         <translation>La commande n&apos;a donnée aucun texte de sortie.</translation>
     </message>
     <message>
-        <location filename="../src/commandhandler.cpp" line="475"/>
+        <location filename="../src/commandhandler.cpp" line="477"/>
         <source>This command is an alias to itself!</source>
         <translation>Cette commande est un alias d&apos;elle-même !</translation>
     </message>
@@ -472,10 +515,6 @@ L&apos;encodage du fichier doit être UTF-8.</translation>
         <source>Select File...</source>
         <translation>Sélectionner un fichier...</translation>
     </message>
-    <message>
-        <source>The name, without the prefix</source>
-        <translation type="vanished">Le nom, sans le préfixe</translation>
-    </message>
     <message>
         <location filename="../src/commandmodule.cpp" line="104"/>
         <source>Enter a system command line to be run, with any needed parameters.
@@ -553,10 +592,6 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         <source>Set an optional reply pattern</source>
         <translation>Définir un modèle de réponse optionnel</translation>
     </message>
-    <message>
-        <source>The name, without the prefix or any spaces</source>
-        <translation type="vanished">Le nom, sans préfixe ni espace</translation>
-    </message>
     <message>
         <location filename="../src/commandmodule.cpp" line="79"/>
         <source>Explanation shown to users with the %1 command</source>
@@ -797,40 +832,55 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         <translation>Comme utilisateur@service</translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="65"/>
+        <location filename="../src/connectiondialog.cpp" line="62"/>
+        <source>Use carefully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/connectiondialog.cpp" line="63"/>
+        <source>This allows connecting to servers with bad security certificates.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/connectiondialog.cpp" line="72"/>
         <source>&amp;Connect</source>
         <translation>&amp;Connecter</translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="75"/>
+        <location filename="../src/connectiondialog.cpp" line="82"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="89"/>
+        <location filename="../src/connectiondialog.cpp" line="96"/>
         <source>XMPP Address (Jabber ID)</source>
         <translation>Adresse XMPP (Jabber ID)</translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="90"/>
+        <location filename="../src/connectiondialog.cpp" line="97"/>
         <source>Password</source>
         <translation>Mot de passe</translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="91"/>
+        <location filename="../src/connectiondialog.cpp" line="98"/>
         <source>Connect Automatically</source>
         <translation>Connecter automatiquement</translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="92"/>
+        <location filename="../src/connectiondialog.cpp" line="99"/>
         <source>Resource</source>
         <translation>Ressource</translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="93"/>
+        <location filename="../src/connectiondialog.cpp" line="100"/>
         <source>Priority</source>
         <translation>Priorité</translation>
     </message>
+    <message>
+        <location filename="../src/connectiondialog.cpp" line="101"/>
+        <source>Ignore SSL errors</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ContactsModule</name>
@@ -979,6 +1029,11 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         <source>Rooms:</source>
         <translation>Salons :</translation>
     </message>
+    <message>
+        <location filename="../src/generalmodule.cpp" line="157"/>
+        <source>Server version: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/generalmodule.cpp" line="295"/>
         <source>%1 joined, out of %2 configured</source>
@@ -1196,52 +1251,52 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/mainwindow.cpp" line="71"/>
+        <location filename="../src/mainwindow.cpp" line="70"/>
         <source>Settings file in use: %1</source>
         <translation>Fichier de paramètres en cours d&apos;utilisation : %1</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="134"/>
+        <location filename="../src/mainwindow.cpp" line="132"/>
         <source>General</source>
         <translation>Général</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="137"/>
+        <location filename="../src/mainwindow.cpp" line="135"/>
         <source>Rooms</source>
         <translation>Salons</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="144"/>
+        <location filename="../src/mainwindow.cpp" line="142"/>
         <source>Contacts</source>
         <translation>Contacts</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="147"/>
+        <location filename="../src/mainwindow.cpp" line="145"/>
         <source>Commands</source>
         <translation>Commandes</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="150"/>
+        <location filename="../src/mainwindow.cpp" line="148"/>
         <source>Room Speech</source>
         <translation type="unfinished">Phrases pour les salons</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="153"/>
+        <location filename="../src/mainwindow.cpp" line="151"/>
         <source>Conversation</source>
         <translation>Conversation</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="156"/>
+        <location filename="../src/mainwindow.cpp" line="154"/>
         <source>Activities</source>
         <translation>Activités</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="159"/>
+        <location filename="../src/mainwindow.cpp" line="157"/>
         <source>Identity</source>
         <translation>Identité</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="162"/>
+        <location filename="../src/mainwindow.cpp" line="160"/>
         <source>Log</source>
         <translation>Journal</translation>
     </message>
@@ -1307,7 +1362,7 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="357"/>
-        <location filename="../src/mainwindow.cpp" line="1073"/>
+        <location filename="../src/mainwindow.cpp" line="1098"/>
         <source>About AkariXB</source>
         <translation>À propos de AkariXB</translation>
     </message>
@@ -1332,162 +1387,167 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         <translation>Dossier de données en cours d&apos;utilisation : %1</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="658"/>
+        <location filename="../src/mainwindow.cpp" line="677"/>
         <source>Connecting...</source>
         <translation>Connexion...</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="700"/>
+        <location filename="../src/mainwindow.cpp" line="695"/>
+        <source>Warning! Ignoring errors in SSL connection to server.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="722"/>
         <source>%1 connected.</source>
         <translation>%1 connecté.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="757"/>
+        <location filename="../src/mainwindow.cpp" line="780"/>
         <source>Aborted connection attempt.</source>
         <translation>Tentative de connexion abandonnée.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="769"/>
+        <location filename="../src/mainwindow.cpp" line="794"/>
         <source>Disconnected.</source>
         <translation>Déconnecté.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="790"/>
+        <location filename="../src/mainwindow.cpp" line="815"/>
         <source>Disconnected</source>
         <translation>Déconnecté</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="791"/>
+        <location filename="../src/mainwindow.cpp" line="816"/>
         <source>Connection to the server was lost.</source>
         <translation>La connexion au serveur a été perdue.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="807"/>
+        <location filename="../src/mainwindow.cpp" line="832"/>
         <source>Connection seems stuck. Trying again...</source>
         <translation>La connexion semble bloquée. Nouvel essai...</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="884"/>
+        <location filename="../src/mainwindow.cpp" line="909"/>
         <source>Presence error %1 from %2: %3</source>
         <translation>Présence d&apos;erreur %1 de %2 : %3</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="901"/>
+        <location filename="../src/mainwindow.cpp" line="926"/>
         <source>%1 wants to subscribe to your presence.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation>%1 souhaite installer un indicateur à votre présence.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="909"/>
+        <location filename="../src/mainwindow.cpp" line="934"/>
         <source>%1 accepted your subscription request.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation>%1 a accepté votre requête de souscription.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="917"/>
+        <location filename="../src/mainwindow.cpp" line="942"/>
         <source>%1 unsubscribed from your presence.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation>%1 a supprimé l&apos;indicateur de votre présence.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="925"/>
+        <location filename="../src/mainwindow.cpp" line="950"/>
         <source>%1 removed your authorization to see their presence.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation>%1 vous a supprimé l&apos;autorisation d&apos;indication de sa présence.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="965"/>
+        <location filename="../src/mainwindow.cpp" line="990"/>
         <source>Received version information from %1:</source>
         <translation>Version obtenue de %1 :</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="988"/>
+        <location filename="../src/mainwindow.cpp" line="1013"/>
         <source>Socket Error</source>
         <translation>Erreur Socket</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="993"/>
+        <location filename="../src/mainwindow.cpp" line="1018"/>
         <source>KeepAlive Error</source>
         <translation>Erreur KeepAlive</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="997"/>
+        <location filename="../src/mainwindow.cpp" line="1022"/>
         <source>XMPP Stream Error</source>
         <translation>Erreur Stream XMPP</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1006"/>
+        <location filename="../src/mainwindow.cpp" line="1031"/>
         <source>Network error: %1</source>
         <translation>Erreur réseau : %1</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1018"/>
+        <location filename="../src/mainwindow.cpp" line="1043"/>
         <source>Chats</source>
         <translation>Discussions</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1081"/>
+        <location filename="../src/mainwindow.cpp" line="1106"/>
         <source>AkariXB is a Jabber/XMPP bot.</source>
         <translation>AkariXB est un robot Jabber/XMPP.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1084"/>
+        <location filename="../src/mainwindow.cpp" line="1109"/>
         <source>You can talk to it, make it join chatrooms, etc.</source>
         <translation>Vous pouvez lui parler, lui faire rejoindre des salons de discussion, etc.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1088"/>
+        <location filename="../src/mainwindow.cpp" line="1113"/>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. If there was another translator before you, add your name after theirs ;)</comment>
         <translation>Traduction française par Adrien DAUGABEL, David GEIGER, Papoteur, Sébastien Morin et Jybz.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1095"/>
+        <location filename="../src/mainwindow.cpp" line="1120"/>
         <source>Thanks to all the testers, translators and packagers, who help make AkariXB better!</source>
         <translation>Merci à tous les testeurs, traducteurs et packageurs, qui contribuent à l&apos;amélioration d&apos;AkariXB !</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1100"/>
+        <location filename="../src/mainwindow.cpp" line="1125"/>
         <source>AkariXB is Free Software, licensed under the GNU GPL license, and uses some Oxygen icons under LGPL license.</source>
         <translation>AkariXB est un logiciel libre, sous licence GNU/GPL, et utilise les icônes Oxygen sous licence LGPL.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1125"/>
+        <location filename="../src/mainwindow.cpp" line="1150"/>
         <source>Offline</source>
         <translation>Hors ligne</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1177"/>
+        <location filename="../src/mainwindow.cpp" line="1202"/>
         <source>Account is not configured</source>
         <translation>Le compte n&apos;est pas configuré</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1276"/>
+        <location filename="../src/mainwindow.cpp" line="1287"/>
         <source>&amp;Hide Window</source>
         <translation>&amp;Cacher la fenêtre</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1283"/>
+        <location filename="../src/mainwindow.cpp" line="1294"/>
         <source>&amp;Show Window</source>
         <translation>&amp;Afficher la fenêtre</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1300"/>
+        <location filename="../src/mainwindow.cpp" line="1311"/>
         <source>Quit?</source>
         <translation>Quitter ?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1301"/>
+        <location filename="../src/mainwindow.cpp" line="1312"/>
         <source>Are you sure?</source>
         <translation>Êtes-vous sûr(e) ?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1303"/>
+        <location filename="../src/mainwindow.cpp" line="1314"/>
         <source>Yes, quit AkariXB</source>
         <translation>Oui, quittez AkariXB</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1303"/>
+        <location filename="../src/mainwindow.cpp" line="1314"/>
         <source>No</source>
         <translation>Non</translation>
     </message>
@@ -1593,10 +1653,6 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
             <numerusform>Sauvegardé %Ln salons.</numerusform>
         </translation>
     </message>
-    <message>
-        <source>%1 as %2</source>
-        <translation type="vanished">%1 comme %2</translation>
-    </message>
     <message>
         <location filename="../src/roommodule.cpp" line="64"/>
         <source>Password</source>
@@ -1623,10 +1679,6 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         <source>Greet people</source>
         <translation>Saluer les gens</translation>
     </message>
-    <message>
-        <source>Speak casually</source>
-        <translation type="vanished">Parler de manière familière</translation>
-    </message>
     <message>
         <location filename="../src/roommodule.cpp" line="163"/>
         <source>Converse</source>
@@ -1770,7 +1822,7 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/roomspeaktab.cpp" line="166"/>
+        <location filename="../src/roomspeaktab.cpp" line="174"/>
         <source>Saved %Ln sentence(s) of type %1.</source>
         <translation>
             <numerusform>Sauvegardé %Ln phrase de type %1.</numerusform>
@@ -1780,30 +1832,18 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
 </context>
 <context>
     <name>StringListWidget</name>
-    <message>
-        <source>Add an item to the list</source>
-        <translation type="vanished">Ajouter un élément à la liste</translation>
-    </message>
-    <message>
-        <source>Edit the selected item (you can also double-click it)</source>
-        <translation type="vanished">Modifier l&apos;élément sélectionné (vous pouvez également double-cliquer dessus)</translation>
-    </message>
-    <message>
-        <source>Remove the selected item</source>
-        <translation type="vanished">Supprimer l&apos;élément sélectionné</translation>
-    </message>
     <message>
         <location filename="../src/stringlistwidget.cpp" line="187"/>
         <source>Update the definition of the item</source>
         <translation>Mettre à jour la définition de l&apos;élément</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="658"/>
+        <location filename="../src/stringlistwidget.cpp" line="659"/>
         <source>Enter text</source>
         <translation>Entrer un texte</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="623"/>
+        <location filename="../src/stringlistwidget.cpp" line="624"/>
         <source>Item text is not valid</source>
         <translation>L&apos;élément texte est invalide</translation>
     </message>
@@ -1813,12 +1853,12 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         <translation>Ajouter un élément à la liste (vous pouvez aussi appuyer sur la touche [Inser])</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="659"/>
+        <location filename="../src/stringlistwidget.cpp" line="660"/>
         <source>Enter a new line of text for the list</source>
         <translation>Entrer une nouvelle ligne de texte pour la liste</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="513"/>
+        <location filename="../src/stringlistwidget.cpp" line="514"/>
         <source>The item already exists</source>
         <translation>L&apos;élément existe déjà</translation>
     </message>
@@ -1858,27 +1898,27 @@ La réponse proviendra de la sortie de la commande sur la console, sauf si vous
         <translation>Supprimer l&apos;élément sélectionné (vous pouvez aussi appuyer sur [Maj]+[Effacer])</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="515"/>
+        <location filename="../src/stringlistwidget.cpp" line="516"/>
         <source>Error: There is already an item in the list with the text %1, and this list does not allow duplicates.</source>
         <translation>Erreur : un élément dans la liste avec le texte %1 existe déjà, et cette liste n&apos;autorise pas les doublons.</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="636"/>
+        <location filename="../src/stringlistwidget.cpp" line="637"/>
         <source>Regular expression is not valid</source>
         <translation>L&apos;expression régulière est invalide</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="638"/>
+        <location filename="../src/stringlistwidget.cpp" line="639"/>
         <source>Syntax error at position %1:</source>
         <translation>Erreur de syntaxe à la position %1 :</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="705"/>
+        <location filename="../src/stringlistwidget.cpp" line="706"/>
         <source>Modify text</source>
         <translation>Modifier le texte</translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="706"/>
+        <location filename="../src/stringlistwidget.cpp" line="707"/>
         <source>Update the text for this item</source>
         <translation>Mettre à jour le texte pour cet élément</translation>
     </message>
